{% extends "wiki/_base.html" %} {% from "macros/box.html" import m_box_content %} {% block content %} {% call m_box_content(_("(changes)")) %} {% set show_controls = revisions|length > 1 %}

{% for rev in revisions %}
- {% if show_controls %}{% endif %} {{ rev.number }}: by {{ rev.author }} at {{ rev.created_at|datetimeformat }} ({{ rev.body_src|length }} {{ _("characters") }})
{% endfor %}

{% if show_controls %}
{% endif %} {% endcall %} {% endblock %}